#
# spec file for package flatpak-builder
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           flatpak-builder
Version:        0.10.9
Release:        lp150.1.1
Summary:        Tool to build flatpaks from source
License:        LGPL-2.1-or-later
Group:          Development/Tools/Building
Url:            http://flatpak.org/
Source:         https://github.com/flatpak/flatpak-builder/releases/download/%{version}/%{name}-%{version}.tar.xz
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  gettext
BuildRequires:  gtk-doc
BuildRequires:  libcap-devel
BuildRequires:  libdwarf-devel
BuildRequires:  pkgconfig
BuildRequires:  xmlto
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(flatpak) >= 0.10.2
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libelf)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(ostree-1) >= 2017.12
Requires:       %{_bindir}/bzip2
Requires:       %{_bindir}/bzr
Requires:       %{_bindir}/eu-strip
Requires:       %{_bindir}/git
Requires:       %{_bindir}/patch
Requires:       %{_bindir}/strip
Requires:       %{_bindir}/tar
Requires:       %{_bindir}/unzip

%description
Tool to build flatpaks from source.
See https://wiki.gnome.org/Projects/SandboxedApps for more information.

%prep
%autosetup

%build
%configure \
	--enable-docbook-docs \
	--with-dwarf-header=%{_includedir}/libdwarf \
	%{nil}
%make_build

%install
%make_install

%files
%license COPYING
%doc NEWS README.md
%doc %{_datadir}/doc/%{name}/
%{_bindir}/flatpak-builder
%{_mandir}/man1/flatpak-builder.1%{ext_man}
%{_mandir}/man5/flatpak-manifest.5%{ext_man}

%changelog
* Mon Mar  5 2018 fcrozat@suse.com
- Update to version 0.10.9:
  + Support -y argument, which passes it on to flatpak install, etc.
  + Fix build on glibc 2.27.
- Changes from version 0.10.8:
  + Fix build on recent glibc.
- Changes from version 0.10.7:
  + Add support for --socket=fallback-x11.
  + Fix assert in --install.
  + Fix --disable-updates for git sources.
  + When mirroring git repos, use a temporary download dir.
  + Support running flatpak-builder inside a flatpak sandbox.
* Wed Dec 20 2017 zaitor@opensuse.org
- Update to version 0.10.6:
  + New checksum types for file/archive sources: md5, sha1, sha512.
  + Support including source snippets from another file, similar to
    how module includes are supported.
  + The app id renaming in the appdata file is now more careful to
    avoid renaming other parts.
  + The cache default repo format for new caches is now
    bare-user-only which means building with flatpak-builder works
    on filesystems that don't support xattrs.
  + New --install argument will install the finished build using
    the new flatpak install install-directly-from-local-repo
    feature. This makes it easier to test local builds.
* Mon Nov 27 2017 adrien.plazas@suse.com
- Update to version 0.10.5:
  + Add support for running tests during the build (disable with
  - -disable-tests).
  + New build-option append-pkg-config to append to
    PKG_CONFIG_PATH.
  + --state-dir option lets you reuse a single directory instead of
    scattered .flatpak-builder dirs for builds, downloads and cache
    data.
  + git: Allow updates with non-fastforwarded branched.
  + Don't fail if app ships both appdata and metainfo file.
  + Support --log-system/session-bus in --run.
* Mon Nov 13 2017 jengelh@inai.de
- Adjust RPM groups.
* Tue Nov  7 2017 adrien.plazas@suse.com
- Update to version 0.10.4:
  + Fixed source bundling of git repos with older versions of git.
  + Allow git sources to use "HEAD" branch.
  + Fixed crashes in some cases of git failure.
* Thu Nov  2 2017 aplazas@suse.com
- Update to version 0.10.3:
  + Yet more fixed or older versions of git. In particular, we
    disable fsck during transfer when doing a shallow clone and the
    git version is less than 1.8.3.2.
- Changes from version 0.10.2:
  + Even more fixes for shallow git clones with older versions of
    git.
  + New property for git sources, disable-shallow-clone which falls
    back to cloning the entire remote.
- Changes from version 0.10.1:
  + Fix handling of shallow git clones with older versions of git.
  + Fix issue where flatpak-builder --run could exit if some thread
    in the parent process exited, exposeb by e.g. gnome-builder.
- Changes from version 0.10.0:
  + We now do shallow clones of git repos when downloading if
    possible.
  + The way the cache works internally was slightly tweaked which
    will cause all existing caches to be rebuilt.
- Changes from version 0.9.99:
  + Fix git source bundling on older git version.
  + New property: appdata-license lets you easily modify the
    appstream license field.
  + New source type "extra-data" which makes it easier to use
    extra-data apps.
  + We now automatically compress debuginfo unless the
    no-debuginfo-compression option is specified.
  + Appstream files called .metainfo.xml are now recognized.
  + New prepare-platform-commands property, similar
    to cleanup-platform-commands, but run before importing all the
    changes from the SDK.
  + We now apply all the deletions that happened in the SDK on the
    base when creating the platform.
- Changes from version 0.9.98:
  + build cache hits are now faster.
  + git sources have a new property "tag" which works the same as
    "branch", but improves readability when referencing a git tag.
  + flatpak-builder --run now passes --with-appdir which is useful
    when testing uninstalled builds.
  + When bundling git repos in .Sources we now make a shallow clone
    which uses a lot less space.
  + .Locale extensions now always set the new locale-subset
    property.
  + locale-subset is supported in the add-extension property.
  + build-options now also supports make-args and make-install
    args, which allows per-arch make flags.
- Bump pkgconfig(flatpak) BuildRequires to 0.10.0.
- Bump pkgconfig(ostree-1) BuildRequires to 2017.12.
* Wed Sep 13 2017 zaitor@opensuse.org
- Initial build for openSUSE, version 0.9.11.
